==> ci-hotel_V1.2.0_20110206.zip: ci-hotel_1.2.0_20110206/system/application/views/admin/plans/form.php <==
<table class="inp">
<tr><th>* プラン名 :</th><td>
<input type="text" name="plan_name" value="<?php echo set_value('plan_name', isset($plan_name) ? $plan_name : ''); ?>" size="80" />
<?php echo form_error('plan_name'); ?>
</td></tr>
<tr><th>* 概要 :</th><td>
<?php display_ck(array('id' => 'summary'), $summary); ?>
<?php echo form_error('summary'); ?>
</td></td>
<tr><th>説明 :</th><td>
<?php display_ck(array('id' => 'description'), $description); ?>
<?php echo form_error('description'); ?>
</td></tr>
<tr><th>* 期間 :</th><td>
<input type="text" name="start_date" id="datepicker1" value="<?php echo set_value('start_date', isset($start_date) ? $start_date : ''); ?>" size="20" />
～
<input type="text" name="end_date" id="datepicker2" value="<?php echo set_value('end_date', isset($start_date) ? $end_date : ''); ?>" size="20" />
<?php echo form_error('start_date'); ?>
<?php echo form_error('end_date'); ?>
</td></tr>
<tr><th>* 最大部屋数 :</th><td>
<input type="text" name="max_rooms" id="s4" value="<?php echo set_value('max_rooms', isset($max_rooms) ? $max_rooms : ''); ?>" size="4" />
<?php echo form_error('max_rooms'); ?>
</td></tr>
<tr><th>* プラン数 :</th><td>
<input type="text" name="default_num" id="s1" value="<?php echo set_value('default_num', isset($default_num) ? $default_num : ''); ?>" size="4" />
<?php echo form_error('default_num'); ?>
</td></tr>
<tr><th>* 人数 :</th><td>
<table>
<tr><td>最小:</td><td>
<input type="text" name="guest_min" id="s2" value="<?php echo set_value('guest_min', isset($guest_min) ? $guest_min : ''); ?>" size="4" />
</td><td>～</td>
<td>最大:</td><td>
<input type="text" name="guest_max" id="s3" value="<?php echo set_value('guest_max', isset($guest_max) ? $guest_max : ''); ?>" size="4" />
</td></tr></table>
<?php echo form_error('guest_min'); ?>
<?php echo form_error('guest_max'); ?>
</td></tr>
<tr><th>* 部屋タイプ :</th><td>
<select name="roomtypeid">
<?php
foreach ($options as $key => $value)
{
    echo '<option value="' . $key . '">' . $value . '</option>';
}
?>
</select>
<?php echo form_error('roomtypeid'); ?>
</td></tr>
<tr><th>* 朝食 :</th><td>
<?php
$options = array('0' => 'なし', '1' => 'あり');
echo form_dropdown('breakfast', $options, set_value('breakfast', isset($breakfast) ? $breakfast : ''));
?>
<?php echo form_error('breakfast'); ?>
</td></tr>

<tr><th>* 夕食 :</th><td>
<?php
$options = array('0' => 'なし', '1' => 'あり');
echo form_dropdown('dinner', $options, set_value('dinner', isset($dinner) ? $dinner : ''));
?>
<?php echo form_error('dinner'); ?>
</td></tr>

<tr><th>* 料金 :</th><td>

<table>
<td></td><td>A日程</td><td>B日程</td><td>C日程</td><td>D日程</td>
<tr><td>大人</td><td>
<input type="text" name="a_basic_price" value="<?php echo set_value('a_basic_price', isset($a_basic_price) ? $a_basic_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="b_basic_price" value="<?php echo set_value('b_basic_price', isset($b_basic_price) ? $b_basic_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="c_basic_price" value="<?php echo set_value('c_basic_price', isset($c_basic_price) ? $c_basic_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="d_basic_price" value="<?php echo set_value('d_basic_price', isset($d_basic_price) ? $d_basic_price : ''); ?>" size="10" />
</td></tr>
<tr><td>子供A</td><td>
<input type="text" name="a_child1_price" value="<?php echo set_value('a_child1_price', isset($a_child1_price) ? $a_child1_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="b_child1_price" value="<?php echo set_value('b_child1_price', isset($b_child1_price) ? $b_child1_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="c_child1_price" value="<?php echo set_value('c_child1_price', isset($c_child1_price) ? $c_child1_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="d_child1_price" value="<?php echo set_value('d_child1_price', isset($d_child1_price) ? $d_child1_price : ''); ?>" size="10" />
</td></tr>
<tr><td>子供B</td><td>
<input type="text" name="a_child2_price" value="<?php echo set_value('a_child2_price', isset($a_child2_price) ? $a_child2_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="b_child2_price" value="<?php echo set_value('b_child2_price', isset($b_child2_price) ? $b_child2_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="c_child2_price" value="<?php echo set_value('c_child2_price', isset($c_child2_price) ? $c_child2_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="d_child2_price" value="<?php echo set_value('d_child2_price', isset($d_child2_price) ? $d_child2_price : ''); ?>" size="10" />
</td></tr>
<tr><td>子供C</td><td>
<input type="text" name="a_child3_price" value="<?php echo set_value('a_child3_price', isset($a_child3_price) ? $a_child3_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="b_child3_price" value="<?php echo set_value('b_child3_price', isset($b_child3_price) ? $b_child3_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="c_child3_price" value="<?php echo set_value('c_child3_price', isset($c_child3_price) ? $c_child3_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="d_child3_price" value="<?php echo set_value('d_child3_price', isset($d_child3_price) ? $d_child3_price : ''); ?>" size="10" />
</td></tr>
<tr><td>子供D</td><td>
<input type="text" name="a_child4_price" value="<?php echo set_value('a_child4_price', isset($a_child4_price) ? $a_child4_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="b_child4_price" value="<?php echo set_value('b_child4_price', isset($b_child4_price) ? $b_child4_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="c_child4_price" value="<?php echo set_value('c_child4_price', isset($c_child4_price) ? $c_child4_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="d_child4_price" value="<?php echo set_value('d_child4_price', isset($d_child4_price) ? $d_child4_price : ''); ?>" size="10" />
</td></tr>
</table>
<?php echo form_error('a_basic_price'); ?>
<?php echo form_error('b_basic_price'); ?>
<?php echo form_error('c_basic_price'); ?>
<?php echo form_error('d_basic_price'); ?>
<?php echo form_error('a_child1_price'); ?>
<?php echo form_error('b_child1_price'); ?>
<?php echo form_error('c_child1_price'); ?>
<?php echo form_error('d_child1_price'); ?>
<?php echo form_error('a_child2_price'); ?>
<?php echo form_error('b_child2_price'); ?>
<?php echo form_error('c_child2_price'); ?>
<?php echo form_error('d_child2_price'); ?>
<?php echo form_error('a_child3_price'); ?>
<?php echo form_error('b_child3_price'); ?>
<?php echo form_error('c_child3_price'); ?>
<?php echo form_error('d_child3_price'); ?>
<?php echo form_error('a_child4_price'); ?>
<?php echo form_error('b_child4_price'); ?>
<?php echo form_error('c_child4_price'); ?>
<?php echo form_error('d_child4_price'); ?>
</td></tr>

</table>
<input type="submit" name="submit" value="送信" />

==> ci-hotel_V1.2.1_20110211.zip: ci-hotel_V1.2.1_20110211/system/application/views/admin/plans/form.php <==
<table class="inp">
<tr><th>* プラン名 :</th><td>
<input type="text" name="plan_name" value="<?php echo set_value('plan_name', isset($plan_name) ? $plan_name : ''); ?>" size="80" />
<?php echo form_error('plan_name'); ?>
</td></tr>
<tr><th>* 概要 :</th><td>
<?php display_ck(array('id' => 'summary'), $summary); ?>
<?php echo form_error('summary'); ?>
</td></td>
<tr><th>説明 :</th><td>
<?php display_ck(array('id' => 'description'), $description); ?>
<?php echo form_error('description'); ?>
</td></tr>
<tr><th>* 期間 :</th><td>
<input type="text" name="start_date" id="datepicker1" value="<?php echo set_value('start_date', isset($start_date) ? $start_date : ''); ?>" size="20" />
～
<input type="text" name="end_date" id="datepicker2" value="<?php echo set_value('end_date', isset($start_date) ? $end_date : ''); ?>" size="20" />
<?php echo form_error('start_date'); ?>
<?php echo form_error('end_date'); ?>
</td></tr>
<tr><th>* 最大部屋数 :</th><td>
<input type="text" name="max_rooms" id="s4" value="<?php echo set_value('max_rooms', isset($max_rooms) ? $max_rooms : ''); ?>" size="4" />
<?php echo form_error('max_rooms'); ?>
</td></tr>

<tr><th>* 最大連泊数 :</th><td>
<input type="text" name="max_days" id="s5" value="<?php echo set_value('max_days', isset($max_days) ? $max_days : ''); ?>" size="4" />
<?php echo form_error('max_days'); ?>
</td></tr>

<tr><th>* プラン数 :</th><td>
<input type="text" name="default_num" id="s1" value="<?php echo set_value('default_num', isset($default_num) ? $default_num : ''); ?>" size="4" />
<?php echo form_error('default_num'); ?>
</td></tr>
<tr><th>* 人数 :</th><td>
<table>
<tr><td>最小:</td><td>
<input type="text" name="guest_min" id="s2" value="<?php echo set_value('guest_min', isset($guest_min) ? $guest_min : ''); ?>" size="4" />
</td><td>～</td>
<td>最大:</td><td>
<input type="text" name="guest_max" id="s3" value="<?php echo set_value('guest_max', isset($guest_max) ? $guest_max : ''); ?>" size="4" />
</td></tr></table>
<?php echo form_error('guest_min'); ?>
<?php echo form_error('guest_max'); ?>
</td></tr>
<tr><th>* 部屋タイプ :</th><td>
<select name="roomtypeid">
<?php
foreach ($options as $key => $value)
{
    echo '<option value="' . $key . '">' . $value . '</option>';
}
?>
</select>
<?php echo form_error('roomtypeid'); ?>
</td></tr>
<tr><th>* 朝食 :</th><td>
<?php
$options = array('0' => 'なし', '1' => 'あり');
echo form_dropdown('breakfast', $options, set_value('breakfast', isset($breakfast) ? $breakfast : ''));
?>
<?php echo form_error('breakfast'); ?>
</td></tr>

<tr><th>* 夕食 :</th><td>
<?php
$options = array('0' => 'なし', '1' => 'あり');
echo form_dropdown('dinner', $options, set_value('dinner', isset($dinner) ? $dinner : ''));
?>
<?php echo form_error('dinner'); ?>
</td></tr>

<tr><th>* 料金 :</th><td>

<table>
<td></td><td>A日程</td><td>B日程</td><td>C日程</td><td>D日程</td>
<tr><td>大人</td><td>
<input type="text" name="a_basic_price" value="<?php echo set_value('a_basic_price', isset($a_basic_price) ? $a_basic_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="b_basic_price" value="<?php echo set_value('b_basic_price', isset($b_basic_price) ? $b_basic_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="c_basic_price" value="<?php echo set_value('c_basic_price', isset($c_basic_price) ? $c_basic_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="d_basic_price" value="<?php echo set_value('d_basic_price', isset($d_basic_price) ? $d_basic_price : ''); ?>" size="10" />
</td></tr>
<tr><td>子供A</td><td>
<input type="text" name="a_child1_price" value="<?php echo set_value('a_child1_price', isset($a_child1_price) ? $a_child1_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="b_child1_price" value="<?php echo set_value('b_child1_price', isset($b_child1_price) ? $b_child1_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="c_child1_price" value="<?php echo set_value('c_child1_price', isset($c_child1_price) ? $c_child1_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="d_child1_price" value="<?php echo set_value('d_child1_price', isset($d_child1_price) ? $d_child1_price : ''); ?>" size="10" />
</td></tr>
<tr><td>子供B</td><td>
<input type="text" name="a_child2_price" value="<?php echo set_value('a_child2_price', isset($a_child2_price) ? $a_child2_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="b_child2_price" value="<?php echo set_value('b_child2_price', isset($b_child2_price) ? $b_child2_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="c_child2_price" value="<?php echo set_value('c_child2_price', isset($c_child2_price) ? $c_child2_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="d_child2_price" value="<?php echo set_value('d_child2_price', isset($d_child2_price) ? $d_child2_price : ''); ?>" size="10" />
</td></tr>
<tr><td>子供C</td><td>
<input type="text" name="a_child3_price" value="<?php echo set_value('a_child3_price', isset($a_child3_price) ? $a_child3_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="b_child3_price" value="<?php echo set_value('b_child3_price', isset($b_child3_price) ? $b_child3_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="c_child3_price" value="<?php echo set_value('c_child3_price', isset($c_child3_price) ? $c_child3_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="d_child3_price" value="<?php echo set_value('d_child3_price', isset($d_child3_price) ? $d_child3_price : ''); ?>" size="10" />
</td></tr>
<tr><td>子供D</td><td>
<input type="text" name="a_child4_price" value="<?php echo set_value('a_child4_price', isset($a_child4_price) ? $a_child4_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="b_child4_price" value="<?php echo set_value('b_child4_price', isset($b_child4_price) ? $b_child4_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="c_child4_price" value="<?php echo set_value('c_child4_price', isset($c_child4_price) ? $c_child4_price : ''); ?>" size="10" />
</td><td>
<input type="text" name="d_child4_price" value="<?php echo set_value('d_child4_price', isset($d_child4_price) ? $d_child4_price : ''); ?>" size="10" />
</td></tr>
</table>
<?php echo form_error('a_basic_price'); ?>
<?php echo form_error('b_basic_price'); ?>
<?php echo form_error('c_basic_price'); ?>
<?php echo form_error('d_basic_price'); ?>
<?php echo form_error('a_child1_price'); ?>
<?php echo form_error('b_child1_price'); ?>
<?php echo form_error('c_child1_price'); ?>
<?php echo form_error('d_child1_price'); ?>
<?php echo form_error('a_child2_price'); ?>
<?php echo form_error('b_child2_price'); ?>
<?php echo form_error('c_child2_price'); ?>
<?php echo form_error('d_child2_price'); ?>
<?php echo form_error('a_child3_price'); ?>
<?php echo form_error('b_child3_price'); ?>
<?php echo form_error('c_child3_price'); ?>
<?php echo form_error('d_child3_price'); ?>
<?php echo form_error('a_child4_price'); ?>
<?php echo form_error('b_child4_price'); ?>
<?php echo form_error('c_child4_price'); ?>
<?php echo form_error('d_child4_price'); ?>
</td></tr>

</table>
<input type="submit" name="submit" value="送信" />
